/*
 * This file is part of the Scandit Data Capture SDK
 *
 * Copyright (C) 2024- Scandit AG. All rights reserved.
 */

#import <UIKit/UIKit.h>

#import <ScanditCaptureCore/SDCBase.h>

NS_ASSUME_NONNULL_BEGIN

NS_SWIFT_NAME(ScanditIconType)
typedef NSString *SDCScanditIconType NS_TYPED_EXTENSIBLE_ENUM;
extern SDCScanditIconType const SDCScanditIconTypeToPick;
extern SDCScanditIconType const SDCScanditIconTypeCheckmark;
extern SDCScanditIconType const SDCScanditIconTypeXMark;
extern SDCScanditIconType const SDCScanditIconTypeQuestionMark;
extern SDCScanditIconType const SDCScanditIconTypeExclamationMark;
extern SDCScanditIconType const SDCScanditIconTypeWrongItem;
extern SDCScanditIconType const SDCScanditIconTypeLowStock;
extern SDCScanditIconType const SDCScanditIconTypeInspectItem;
extern SDCScanditIconType const SDCScanditIconTypeExpiredItem;
extern SDCScanditIconType const SDCScanditIconTypeFragileItem;
extern SDCScanditIconType const SDCScanditIconTypeStarFilled;
extern SDCScanditIconType const SDCScanditIconTypeStarHalfFilled;
extern SDCScanditIconType const SDCScanditIconTypeStarOutlined;
extern SDCScanditIconType const SDCScanditIconTypeArrowRight;
extern SDCScanditIconType const SDCScanditIconTypeArrowLeft;
extern SDCScanditIconType const SDCScanditIconTypeArrowUp;
extern SDCScanditIconType const SDCScanditIconTypeArrowDown;
extern SDCScanditIconType const SDCScanditIconTypeChevronRight;
extern SDCScanditIconType const SDCScanditIconTypeChevronDown;
extern SDCScanditIconType const SDCScanditIconTypeChevronUp;
extern SDCScanditIconType const SDCScanditIconTypeChevronLeft;
extern SDCScanditIconType const SDCScanditIconTypePrint;

NS_SWIFT_NAME(ScanditIconShape)
typedef NSString *SDCScanditIconShape NS_TYPED_EXTENSIBLE_ENUM;
extern SDCScanditIconShape const SDCScanditIconShapeCircle;
extern SDCScanditIconShape const SDCScanditIconShapeSquare;

SDC_EXPORTED_SYMBOL
NS_SWIFT_NAME(ScanditIcon)
@interface SDCScanditIcon : NSObject

@property (nonatomic, strong, nullable, readonly) SDCScanditIconType icon;
@property (nonatomic, strong, nullable, readonly) UIColor *iconColor;
@property (nonatomic, strong, nullable, readonly) UIColor *backgroundColor;
@property (nonatomic, strong, nullable, readonly) UIColor *backgroundStrokeColor;
@property (nonatomic, assign, readonly) CGFloat backgroundStrokeWidth;
@property (nonatomic, strong, nullable, readonly) SDCScanditIconShape backgroundShape;
@property (nonatomic, nonnull, readonly) NSString *JSONString;

+ (nullable instancetype)iconFromJSONString:(NSString *)JSONString
                                      error:(NSError *_Nullable *_Nullable)error;
+ (instancetype)new NS_UNAVAILABLE;
- (instancetype)init NS_UNAVAILABLE;

@end

SDC_EXTERN NSString *NSStringFromScanditIconType(SDCScanditIconType type);
SDC_EXTERN BOOL SDCScanditIconTypeFromJSONString(NSString *_Nonnull JSONString,
                                                 SDCScanditIconType _Nonnull *_Nonnull type);
SDC_EXTERN NSString *NSStringFromScanditIconShape(SDCScanditIconShape shape);
SDC_EXTERN BOOL SDCScanditIconShapeFromJSONString(NSString *_Nonnull JSONString,
                                                  SDCScanditIconShape _Nonnull *_Nonnull type);

NS_ASSUME_NONNULL_END
